@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4012';
+our $VERSION = '0.4100';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -11,6 +11,7 @@ use List::Util qw(sum0);
 use Math::Bezier ();
 use MIDI::Util qw(dura_size reverse_dump set_chan_patch set_time_signature);
 use Moo;
+use Music::CreatingRhythms ();
 use Music::Duration ();
 use Music::RhythmSet::Util qw(upsize);
 use namespace::clean;
@@ -552,6 +553,15 @@ sub add_fill {
 }
 
 
+sub euclidean {
+    my ($self, $p, $n) = @_;
+    return '' unless $n;
+    my $mcr = Music::CreatingRhythms->new;
+    my $sequence = $mcr->euclid($p, $n);
+    return join '', @$sequence;
+}
+
+
 sub set_time_sig {
     my ($self, $signature, $set) = @_;
     $self->signature($signature) if $signature;
@@ -612,7 +622,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4012
+version 0.4100
 
 =head1 SYNOPSIS
 
@@ -653,10 +663,13 @@ version 0.4012
 
  # Same but with beat-strings:
  $d->sync_patterns(
-    $d->open_hh => [ ('1111') x $d->bars ],
-    $d->snare   => [ ('0101') x $d->bars ],
-    $d->kick    => [ ('1010') x $d->bars ],
- );
+    $d->open_hh => [ '1111' ],
+    $d->snare   => [ '0101' ],
+    $d->kick    => [ '1010' ],
+ ) for 1 .. $d->bars ;
+
+ my $patterns = [ $d->euclidean(5, 16), $d->euclidean(7, 16) ];
+ $d->pattern( instrument => $d->kick, patterns => $patterns );
 
  $d->write;
 
@@ -1011,11 +1024,11 @@ Defaults:
 
   $d->sync_patterns( $instrument1 => $patterns1, $inst2 => $pats2, ... );
   $d->sync_patterns(
-      $d->open_hh => [ ('11111111') x $d->bars ],
-      $d->snare   => [ ('0101') x $d->bars ],
-      $d->kick    => [ ('1010') x $d->bars ],
+      $d->open_hh => [ '11111111') ],
+      $d->snare   => [ '0101' ],
+      $d->kick    => [ '1010' ],
       duration    => $d->eighth, # render all notes at this level of granularity
-  );
+  ) for 1 .. $d->bars;
 
 Execute the C<pattern> method for multiple voices.
 
@@ -1047,6 +1060,12 @@ is a three-note, eighth-note snare fill.
 
 * This method is not right at all and is still in development.
 
+=head2 euclidean
+
+  $pattern = $d->euclidean($p, $n);
+
+Return the Euclidean bitstring pattern for B<p> onsets over B<n> beats.
+
 =head2 set_time_sig
 
   $d->set_time_sig;
@@ -1104,7 +1123,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Gene Boggs.
+This software is copyright (c) 2014-2023 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
